@@ -11,11 +11,13 @@ from .PeriodicContextTable import PeriodicContextTable
 from .PeriodicElement import PeriodicElement
 from .PeriodicFilter import PeriodicFilter
 from .PeriodicTableInput import PeriodicTableInput
+from .BibCard import BibCard
 from .BibjsonCard import BibjsonCard
 from .BibjsonFilter import BibjsonFilter
 from .DownloadButton import DownloadButton
 from .DownloadDropdown import DownloadDropdown
 from .GlobalSearchBar import GlobalSearchBar
+from .OpenAccessLink import OpenAccessLink
 from .SearchUI import SearchUI
 from .Select import Select
 
@@ -33,11 +35,13 @@ __all__ = [
     "PeriodicElement",
     "PeriodicFilter",
     "PeriodicTableInput",
+    "BibCard",
     "BibjsonCard",
     "BibjsonFilter",
     "DownloadButton",
     "DownloadDropdown",
     "GlobalSearchBar",
+    "OpenAccessLink",
     "SearchUI",
     "Select"
 ]
\ No newline at end of file
